package com.zehong.web.controller.operationMonitor;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TInspectionResult;
import com.zehong.system.service.ITInspectionResultService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 巡检结果采集Controller
 *
 * @author zehong
 * @date 2026-03-14
 */
@RestController
@RequestMapping("/inspection/result")
public class TInspectionResultController extends BaseController
{
    @Autowired
    private ITInspectionResultService tInspectionResultService;

    /**
     * 查询巡检结果采集列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TInspectionResult tInspectionResult)
    {
        startPage();
        List<TInspectionResult> list = tInspectionResultService.selectTInspectionResultList(tInspectionResult);
        return getDataTable(list);
    }

    /**
     * 导出巡检结果采集列表
     */
    @Log(title = "巡检结果采集", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TInspectionResult tInspectionResult)
    {
        List<TInspectionResult> list = tInspectionResultService.selectTInspectionResultList(tInspectionResult);
        ExcelUtil<TInspectionResult> util = new ExcelUtil<TInspectionResult>(TInspectionResult.class);
        return util.exportExcel(list, "巡检结果采集数据");
    }

    /**
     * 获取巡检结果采集详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tInspectionResultService.selectTInspectionResultById(id));
    }

    /**
     * 新增巡检结果采集
     */
    @Log(title = "巡检结果采集", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TInspectionResult tInspectionResult)
    {
        return toAjax(tInspectionResultService.insertTInspectionResult(tInspectionResult));
    }

    /**
     * 修改巡检结果采集
     */
    @Log(title = "巡检结果采集", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TInspectionResult tInspectionResult)
    {
        return toAjax(tInspectionResultService.updateTInspectionResult(tInspectionResult));
    }

    /**
     * 删除巡检结果采集
     */
    @Log(title = "巡检结果采集", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tInspectionResultService.deleteTInspectionResultByIds(ids));
    }
}